@@ -290,7 +290,7 @@ specification to other things in your application. Example:
   use Swagger2;
   my $swagger = Swagger2->new->load($url);
   plugin Swagger2 => {swagger => $swagger2};
-  app->defaults(swagger_spec => $swagger->tree);
+  app->defaults(swagger_spec => $swagger->api_spec);
 
 Either this parameter or C<url> need to be present.
 
@@ -311,7 +311,7 @@ sub register {
 
   $swagger = $config->{swagger} || Swagger2->new->load($config->{url} || '"url" is missing');
   $swagger = $swagger->expand;
-  $paths   = $swagger->tree->get('/paths') || {};
+  $paths   = $swagger->api_spec->get('/paths') || {};
 
   $self->url($swagger->url);
   $app->helper(render_swagger => \&render_swagger) unless $app->renderer->get_helper('render_swagger');
@@ -339,17 +339,18 @@ sub register {
         "($type$name)";
       }/ge;
 
-      my $name = decamelize(ucfirst($info->{operationId} || $route_path));
       warn "[Swagger2] Add route $http_method $route_path\n" if DEBUG;
-      $r->$http_method($route_path => $self->_generate_request_handler($name, $info));
+      $r->$http_method($route_path => $self->_generate_request_handler($route_path, $info));
     }
   }
 }
 
 sub _generate_request_handler {
-  my ($self, $method, $config) = @_;
+  my ($self, $route_path, $config) = @_;
+  my $op         = $config->{operationId} || $route_path;
+  my $method     = decamelize(ucfirst $op);
   my $controller = $config->{'x-mojo-controller'} or _die($config, "x-mojo-controller is missing in the swagger spec");
-  my $defaults = {};
+  my $defaults   = {};
   my $handler;
 
   $handler = sub {
@@ -367,7 +368,7 @@ sub _generate_request_handler {
     unless ($method_ref) {
       $c->app->log->error(
         qq(Can't locate object method "$method" via package "$controller. (Something is wrong in @{[$self->url]})"));
-      return $c->render_swagger($self->_not_implemented('Method not implemented.'), {}, 501);
+      return $c->render_swagger($self->_not_implemented(qq(Method "$op" not implemented.)), {}, 501);
     }
 
     bless $c, $controller;    # ugly hack?
